@@ -11,7 +11,7 @@ struct MathOp {
 }
 
 fn main() {
-  let platform = v8::new_default_platform().unwrap();
+  let platform = v8::new_default_platform(0, false).make_shared();
   v8::V8::initialize_platform(platform);
   v8::V8::initialize();
 
